#
# spec file for package python-django-pipeline
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-django-pipeline
Version:        2.0.8
Release:        2.11
Summary:        An asset packaging library for Django
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jazzband/django-pipeline
Source:         https://files.pythonhosted.org/packages/source/d/django-pipeline/django-pipeline-%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module jsmin}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module slimit}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-Jinja2
BuildArch:      noarch
%python_subpackages

%description
Pipeline is an asset packaging library for Django, providing both CSS and
JavaScript concatenation and compression, built-in JavaScript template support,
and optional data-URI image and font embedding.

%prep
%setup -q -n django-pipeline-%{version}
# Make one test compatible with Django 4.1
sed -i 's/type="text\/css" //' tests/tests/test_forms.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# we do not have python-css-html-js-minify, because it is nearly unpackageable (missing licenses, no tags on GitHub)
PYTHONPATH=.
export DJANGO_SETTINGS_MODULE=tests.settings
%pytest -k "not test_csshtmljsminify"

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/pipeline/
%{python_sitelib}/*django_pipeline*/

%changelog
* Sat Sep  3 2022 John Vandenberg <jayvdb@gmail.com>
- Make one test compatible with Django 4.1
* Fri Feb 25 2022 Matej Cepl <mcepl@suse.com>
- Update to 2.0.8:
  - Added Django 4.0 compatibility.
  - Introduce CODE_OF_CONDUCT.md for the project.
  - Add precision in the documentation for PipelineCachedStorage.
  - Drop support for slimit compressor due to package not
    released an official version for Python 3 and not any new
    package release from 2013.
  - Update package.json due to CoffeeScript on NPM has moved to
    "coffeescript"
  - Update setup.py with Django 4.0 and Python 3.10
  - Add support for Terser.
  - Fix django warnings.
* Thu Sep 10 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.0.5
  * Definitely drop the support of Python 2.
  * Drop support for Python 3.5
  * Change import MutableMapping from collections.abc.
  * Remove futures from pipeline setup.py requirements.
  * Adding Django 3.1 compatibility.
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop unused patch django-pipeline-setpcfg.patch
- Fix build wihtout python2
* Thu Jan  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Apply an optimization to save time during development. Thank to @blankser
  * Edit setup.py to follow the recommendation of the documentation. Thank to @shaneikennedy
  * Add tests for Django 3.0 and Python 3.8
  * Add alternatives imports for django.utils.six, who has been removed in Django 3.0
* Wed Aug  8 2018 jengelh@inai.de
- Fix name repetition in summary (rpmlint).
* Wed Aug  8 2018 tchvatal@suse.com
- Update to 1.6.14:
  * latest release to support newest django releases
- Switch to singlespec
- Add patch to pass tests django-pipeline-setpcfg.patch
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Feb 27 2013 alexandre@exatati.com.br
- Update to 1.3.6:
  - Make our threaded code compatible with python 3.
* Wed Feb 27 2013 alexandre@exatati.com.br
- Update to 1.3.5:
  - Run compilers in threads, should improve performance in DEBUG mode.
* Mon Feb 25 2013 p.drouand@gmail.com
- Update to version 1.3.4:
  * Fix false errors on subprocess.
  * Don't run MinifyHTMLMiddleware when DEBUG is True.
* Mon Feb 18 2013 alexandre@exatati.com.br
- Update to 1.3.3:
  * Fix subprocess calls.
* Sun Feb 17 2013 p.drouand@gmail.com
- Update to version 1.3.2:
  * Jinja2 support is back.
  * Many small improvements in documentation.
* Sun Feb  3 2013 alexandre@exatati.com.br
- Update to 1.3.0:
  * Add support Python 3, with some help from Alan Lu.
  * Add support for Django 1.5.
  * Remove support for Django < 1.4.
  * Drop support for Python < 2.6.
  * Drop support for ``staticfiles`` app, in favor of
    django.contrib.staticfiles.
  * Drop PIPELINE settings, in favor of DEBUG to avoid confusion.
  * Drop support for jinja2 temporarily.
- Aditional changes from 1.2.24
  * Fix yui/yuglify settings overriding each other. Thanks to
    Fábio Santos.
- Aditional changes from 1.2.23
  * Separate yuglify compressor from YUI compressor.
  * Improve HTML compression middleware.
- Aditional changes from 1.2.22
  * Better compressor error messages. Thanks to Steven Cummings.
  * Improve installation documentation. Thanks to Steven Cummings.
  * Fix packaging metadata. Thanks to Rui Coelho for noticing it.
  * Add documentation about non-packing storage.
- Aditional changes from 1.2.21
  * Run stylus even if file is considered outdated.
- Aditional changes from 1.1.20
  * Ensure yui-compressor can still use YUICompressor.
- Aditional changes from 1.2.19
  * *BACKWARD INCOMPATIBLE** : Replace python cssmin compressor
    to run the command (works for python or node implementation)
- Aditional changes from 1.2.18
  * **BACKWARD INCOMPATIBLE** : Replace yui-compressor by yuglify,
    check your configuration.
  * Use finders in manifest. Thanks to Sjoerd Arendsen.
- Aditional changes from 1.2.17
  * Fully tested windows compatibility. Thanks to Idan Zalzberg.
- Aditional changes from 1.2.16
  * Fix manifesto module. Thanks to Zenobius Jiricek.
  * Ensure coffee-script compiler don't try to overwrite file.
    Thanks to Teo Klestrup Röijezon.
- Aditional changes from 1.2.15
  * Ensure asset url are build with posixpath.
  * Deal with storage prefix properly.
* Sat Aug  4 2012 alexandre@exatati.com.br
- Initial package (1.2.14) for openSUSE.
